import React, { useContext, useMemo, useState } from "react";
import { motion } from "framer-motion";
import {
	LikeFilled,
	LikeOutlined,
	EyeOutlined,
	CommentOutlined,
	SendOutlined,
	DeleteFilled,
	DeleteOutlined,
} from "@ant-design/icons";
import { Button, Tooltip } from "antd/lib";
import { PostDetailContext } from "../context/PostDetailContext";
import PostLikeButton from "./PostLikeButton";
import { Modal } from "antd";
import { ExclamationCircleOutlined } from "@ant-design/icons";

const { confirm } = Modal;
import PostResources from "../PostResources";
import PostHateButton from "./PostHateButton";
import { useAuth } from "@web/src/providers/auth-provider";
import { RolePerms } from "@nice/common";
import { usePost } from "@nice/client";
import { useNavigate } from "react-router-dom";
import toast from "react-hot-toast";
import LimitedStaffSelect from "../../../staff/limited-staff-select";

export function StatsSection() {
	const { post } = useContext(PostDetailContext);
	const { hasSomePermissions } = useAuth();
	const [isResending, setIsResending] = useState(false);
	const [receiverIds, setReceiverIds] = useState(
		post?.receivers?.map((receiver) => receiver?.id)?.filter(Boolean)
	);
	const showResend = () => {
		setIsResending(true);
	};

	async function handleResend() {
		try {
			await update.mutateAsync({
				where: {
					id: post?.id,
				},
				data: {
					receivers: {
						connect: receiverIds
							?.filter(Boolean)
							?.map((id) => ({ id })),
					},
				},
			});
			toast.success("分发成功");
		} catch (err) {
			console.log(err);
		}
		setIsResending(false);
	}

	const handleCancelResend = () => {
		setIsResending(false);
	};
	const navigate = useNavigate();
	const canEdit = useMemo(() => {
		return hasSomePermissions(RolePerms.MANAGE_ANY_POST);
	}, [hasSomePermissions, post]);
	const { update } = usePost();

	const showDeleteConfirm = () => {
		confirm({
			title: "确定要删除这条记录吗?",
			icon: <ExclamationCircleOutlined />,
			content: "删除后将无法恢复",
			okText: "确定",
			okType: "danger",
			cancelText: "取消",
			centered: true, // 添加这一行
			onOk() {
				deleteById();
			},
			onCancel() {
				console.log("取消删除");
			},
		});
	};

	async function deleteById() {
		try {
			await update.mutateAsync({
				where: {
					id: post.id,
				},
				data: {
					deletedAt: new Date(),
				},
			});
			navigate(-1);
			toast.success("删除成功");
		} catch (err) {
			console.log(err);
			toast.error("删除失败");
		}
	}
	return (
		<div className="mt-6 flex flex-wrap gap-4  justify-end items-center">
			<div className=" flex gap-2">
				<Button
					title="浏览量"
					type="text"
					style={{
						color: "#4b5563",
					}}
					shape="round"
					icon={<EyeOutlined />}>
					<span className="mr-1">浏览量</span>
					{post?.views}
				</Button>
				<Button
					type="text"
					style={{
						color: "#4b5563",
					}}
					title="回复数"
					shape="round"
					icon={<CommentOutlined />}>
					<span className="mr-1">回复数</span>
					{post?.commentsCount}
				</Button>

				<PostHateButton post={post}></PostHateButton>
				<PostLikeButton post={post}></PostLikeButton>
				{canEdit && (
					<>
						<Button
							type="text"
							style={{
								color: "#00308a",
							}}
							shape="round"
							icon={<SendOutlined />}
							onClick={() => showResend()}>
							<span className="mr-1">分发</span>
						</Button>
						<Modal
							centered
							title="选择分发领导"
							visible={isResending}
							onOk={handleResend}
							onCancel={handleCancelResend}>
							<div className="flex flex-1 justify-center">
								<LimitedStaffSelect
									value={receiverIds}
									multiple
									onChange={(value) => {
										setReceiverIds(value as string[]);
									}}
									style={{
										width: "90%",
									}}
								/>
							</div>
						</Modal>
					</>
				)}
				{canEdit && (
					<Button
						type="text"
						style={{
							color: "#ff0000",
						}}
						onClick={showDeleteConfirm}
						shape="round"
						icon={<DeleteOutlined />}>
						<span className="mr-1">删除</span>
					</Button>
				)}
			</div>
		</div>
	);
}
